HasteBuilder class

Inheritance
Mixed-in types

Constructors

HasteBuilder({Key? key, required Widget builder(BuildContext context, Haste actions)})
const

Properties

builder Widget Function(BuildContext context, Haste actions)
final
dispose DisposeActionBuilder
no setterinherited
future FutureActionBuilder
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
init InitActionBuilder
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
memo MemoActionBuilder
no setterinherited
onChange OnChangeActionBuilder
no setterinherited
previous PreviousActionBuilder
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state StateActionBuilder
no setterinherited
stream StreamActionBuilder
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() HasteElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited